@@ -1,6 +1,6 @@
 
 /*
- * $Id: squid.h,v 1.19.4.46 1996/08/30 22:53:34 wessels Exp $
+ * $Id: squid.h,v 1.19.4.47 1996/09/03 15:50:09 wessels Exp $
  *
  * AUTHOR: Duane Wessels
  *
@@ -272,6 +272,6 @@ extern void send_announce _PARAMS((void));
 extern int sslStart _PARAMS((int fd, char *, request_t *, char *, int *sz));
 extern char *storeToString _PARAMS((StoreEntry *));
 extern time_t ttlSet _PARAMS((StoreEntry *));
-extern void ttlAddToList _PARAMS((char *, time_t, int, time_t));
+extern void ttlAddToList _PARAMS((char *, int, time_t, int, time_t));
 extern int waisStart _PARAMS((int, char *, method_t, char *, StoreEntry *));
 extern void storeDirClean _PARAMS((void));
